function setup=wavepktj(setup)
% Wave packets in 1-D
% Export to jpeg for off-line processing to DviX
% Usage: 
%   setup=wavepkt([setup])
%               if called with no arguments, a default is supplied

% Begin user interface 
    
  entries={'Size',...
        'Grid',...
        'mass',...
        'time',...
	   'snapshots',...
	   'ErMode',...
	   'initMom',...
	   'x_0',...
	   '\sigma',...
       'potential strength',...
       'movie prefix',...
       'refine',...
       'pot_param'
	  };
  
  
  if(nargin<1)
    default={'10.0',... % Size
	     '512',...  % NGrid
	     '1.0',...  % mass
	     '50.0',...   % time
	     '100',...   % snapshots
	     'normal',...   % EraseMode 
	     '0.0',...
	     '-1.0',...
	     '0.50',...
         '1.0',...
         'sch1_',...
         '8',...
         '1.0'
	    };
    
  else
    default=setup;
  end
  
  heading='Initial data';
  lines=1;
  AddOpts.Resize = 'on';
  AddOpts.WindowStyle = 'normal';
  AddOpts.Interpreter = 'tex';
  
  setup=inputdlg(entries,heading,lines,default,AddOpts);
  
  L                =str2double(setup{1});
  N                =str2double(setup{2});
  mass             =str2double(setup{3});
  t1               =str2double(setup{4});
  snapshots        =str2double(setup{5});
  plotmode         =setup{6};
  mom              =str2double(setup{7});
  x0               =str2double(setup{8});
  sigma            =str2double(setup{9});
  V0               =str2double(setup{10})
  moviename        =setup{11};
  refine           =str2double(setup{12})
  modes            =[{'normal'},{'xor'},{'none'}];
  
  if(nnz(strcmp(modes,plotmode))==0),
    disp(['Unknown mode: ' plotmode]);
    disp('Legal modes: ')
    disp(modes);
    plotmode='normal';
  end
  
  % end user interface
  
  %  coordinate grid
  
  dx  = 2*L/N
  x   = -L*(1-1/N) : dx : L*(1-1/N); 
  x   =  x';
size(x)
  % build momentum space lattice
  
  k = fftshift(pi*(-N/2:(N/2-1))/L)';
  k2=k.^2;
  tau=t1/snapshots;
  t=tau;
  k2=min(k2, 2* mass* pi *refine/tau);
  
  omega=str2double(setup{13});
  %
  % Insert potential here 
  %
  % V = 0.5*V0*mass*omega^2*x.^2;
  % V = V0*mass*omega*abs(x);
  % V = V0 * (abs(x)<omega);
  %  V = V0 * (x.^2 - omega^2).^2/omega^4;
  
  V  = cos(2*pi*x/20);
  
  V = min(V, pi*refine/tau);
  
  U = exp(-1i*tau*V/refine);
  W = exp(-0.5*1i*k2/mass*tau/refine);
  U2 = exp(-0.5*1i*tau*V/refine);
  
%prepare initial wfcn

psi=exp(-(x-x0).^2/4/sigma+1i*mom*x)/(2*pi*sigma).^(1/4);
a = x(2)-x(1);
psi=psi/sqrt(a*sum(abs(psi).^2));
scrsz = get(0,'ScreenSize');

fig=figure('Position',[1, 1, scrsz(3)/2, scrsz(4)/2])

set(fig,'DoubleBuffer','on');
set(gca,'NextPlot','replace','Visible','off')

area(x,V/V0*max(abs(psi))^2/4,'Facecolor','y')
hold on
plot(x, abs(psi).^2, 'r','LineWidth', 1);

xlabel('x'); ylabel('|\psi |^2');title(['Schroedinger Wave ' ...
                    'packet']);

axis([min(x),max(x),0, max(abs(psi).^2)]);

set(gca,'Color','b')
set(gcf,'DoubleBuffer','on');
h=area(x, abs(psi).^2,'Facecolor', 'c','EraseMode',plotmode);

% compute total energy

Ep=sum(V.*abs(psi).^2)/sum(abs(psi).^2);
phi=fft(psi);
%dk=k(2)-k(1);
%phi=phi/sqrt(dk*sum(abs(phi).^2));
Ek=sum(k2.*abs(phi).^2/(2*mass))/sum(abs(phi).^2);

E=Ep+Ek;
E=E/V0*max(abs(psi))^2/4
plot([x(1),x(end)],E*[1,1],'r');
% main loop
n=1;

while(t<t1),
    set(h,'Ydata',abs(psi).^2);
    drawnow
    psi=psi.*U2;
    for j=1:refine
        phi = fft(psi);
        psi = U.*ifft(phi.*W);
    end
    psi=psi.*conj(U2);
    
    t=t+tau ;
    ver=sprintf('%d',1000000+n);
    home;
    n=n+1
    print('-djpeg75',['images/',moviename,ver]);
end


hold off;

