function [F,set1,set2] = wms2Dcam
% Wave packets in 2-D
%  E.Onofri, 2004 
    
  fftw('planner','exhaustive')

Pot1 = '.50*ones(size(x)) .* Ball(x,y,20)';

	    
Pot2 = '1.0*ones(size(x)).*(Ball(x,y,10)+Ball(x-20,y-20,10)+Ball(x-20,y+20,10)+Ball(x,y-40,10)+Ball(x,y+40,10)+Ball(x-20,y+60,10)+Ball(x-20,y-60,10)+Ball(x,y+80,10)+Ball(x,y-80,10))';

Pot3 =  '10*ones(size(x)).*(Ball(x,y,12)+Barrier(x,y,12,[0,32],1)+Barrier(x,y,12,[0,32],-1))';

  selection = {'Resume','New setup'};
  choice    = menu('Start',selection);

  entries1 = {'Size',...
	    'Grid',...
	    'mass',...
	    'time',...
	    'snapshots',...
	    'initMom',...
	    'x_0',...
	    '\sigma',...
	    'V(x)',...
	   };
  
  entries2 = {'save results',...
    'save file name',...
	    'plot every...',...
	    'scale image',...
	    'noise level',...
	    'color code',...
	    'view angle',...
	    'transparency',...
	    'capture'
	  };
  
  switch choice
   case 1				% resume a previous run
    d = dir('*.mat');
    files = {d.name};
    fprompt = {num2cell((1:max(size(files)))'), files'};
    [fprompt{1,:}]
    fn = input('choose number > ');
    eval(['load ' files{fn}]);
    def1 = set1;
    def2 = set2;
   case 2				% new run
    
    if(nargin<1)
      def1 = {'[128.0,128.0]',... % Size
	      '[256,256]',...  % NGrid
	      '1.0',...  % mass
	      '100.0',...   % time
	      '500',...   % snapshots
	      '[.5,0.]',...
	      '[-60.0,0.0]',...
	      '[36.0,36*36.0]',...
	      Pot1
	     };
      
      def2 = {'y',...
	      'FRINGES',...
	      '4',...
	      '2',...
	      '.001',...
	      'phase',...
	      '[45,20]',...
	      '.5',...
	      'n'
	     };
      
    else
      def1 = set1;
      def2 = set2;
    end
  end

  head1 = 'Initial data';
  head2 = 'graphics data';
  lines = 1;
  AddOpts.Resize  =  'on';
  AddOpts.WindowStyle  =  'normal';
  AddOpts.Interpreter  =  'tex';
  
  set1 = inputdlg(entries1,head1,lines,def1,AddOpts);
  set2 = inputdlg(entries2,head2,lines,def2,AddOpts);
  
  L = str2num(set1{1});
  L1 = L(1);
  L2 = L(2);

  Ngrid = str2num(set1{2});
  N1 = Ngrid(1);
  N2 = Ngrid(2);
  
  mass = str2num(set1{3});
  Tmax = str2num(set1{4});
  snapshots = str2num(set1{5});

  mom = str2num(set1{6});
  p1 = mom(1);
  p2 = mom(2);
  
  x0 = str2num(set1{7});
  y0 = x0(2);
  x0 = x0(1);
  
  sigma = str2num(set1{8});
  s1 = sigma(1);
  s2 = sigma(2);
  
  iter = str2num(set2{3});
  scim = str2num(set2{4});
  nl = str2num(set2{5});
  color_code = set2{6};

  angles = str2num(set2{7});
  Latin = angles(1);
  Latout = angles(2);

  transp = str2double(set2{8});
  capt = set2{9};

  x  =  linspace(-L1,L1,N1);
  ytmp = linspace(-L2,L2,N2);
  y = ytmp'*ones(size(x));
  x = ones(size(ytmp'))*x;

  r = sqrt(x.^2+y.^2);
  
  kx = pi*(0:N1-1)/L1;    % build momentum space lattice
  ky = pi*(0:N2-1)/L2;    % build momentum space lattice
  kx(N1/2:N1) = kx(N1/2:N1)-pi*N1/L1;
  ky(N2/2:N2) = ky(N2/2:N2)-pi*N2/L2;
  
  kx = kx*(N1-1)/N1;
  kytmp = ky*(N2-1)/N2;

  ky = kytmp'*ones(size(kx));
  kx = ones(size(kytmp'))*kx;

  k2 = kx.^2+ky.^2;

  tau = Tmax/snapshots;
  t = tau;

  eval(['V=',set1{9},';']);
  
  V = min(V,pi/tau);			% antialiasing
  V = max(V,-pi/tau);			% antialiasing
  
  psi = exp(-(x-x0).^2/2/s1 ...
	  -(y-y0).^2/2/s2 ...
	  +i*p1*x+i*p2*y)/(pi*s1*pi*s2).^(1/4);
  
  if(~isempty(findstr('phase',color_code))),
    C = arg(psi,nl);
  else
    C = abs(psi);
  end

  % Calculate kinetic energy
  
  phi=fft2(psi);
  E = sum(sum(abs(phi).^2 .* k2))/(2*mass)/ sum(sum(abs(phi).^2));
  E = E/max(max(abs(V)));
  disp(['kinetic energy =',num2str(E),'%']);
  
  surf(x, y, V/max(max(abs(V))),...
       'FaceAlpha',transp,...
       'EdgeColor','interp',...
       'SpecularColorReflectance',.5,...
       'BackFaceLighting','lit');

  xlabel('x')
  ylabel('y')
  set(gca,'nextplot','replacechildren');
  hold on 
  fill3(L1*[-1,1,1,-1,-1],L2*[1,1,-1,-1,1],E*[1,1,1, 1,1],'y', ...
        'FaceAlpha',transp/4);
  hold on
  drawnow
  
  pause
  
  surf(x, y, scim*abs(psi), C,...
       'FaceColor','interp',...
       'EdgeColor','interp',...
       'SpecularColorReflectance',.8,...
       'BackFaceLighting','lit');
  
  hold on
  
  xlabel('x')
  ylabel('y')
  %  title('2-D Schroedinger Equation')
  material shiny
  shading interp
  Long = -30.;
  
  view([Long,Latin]);

  axis off
  axis([-L1,L1,-L2,L2,0,max(max(abs(psi)))])
  daspect([1,1,1/sqrt(L1*L2)])
  set(gcf,'DoubleBuffer','on');
  set(gca,'nextplot','replacechildren');
  
  
  drawnow
  
  K = min(0.5*k2/mass,pi/tau);
  
  
  W = exp(-i*K*tau);
  U = exp(-0.5*i*V*tau);
    
  clear K kx ky k2  r  ytmp kytmp 
  
  n = 1;

  while(t<Tmax),
    
    for j = 1:iter,
      psi = psi.*U;
      phi = fft2(psi);
      psi = ifft2(phi.*W);
      psi = psi.*U;
      t = t+tau; 
    end
    
    if(~isempty(findstr('phase',color_code))),
      C = arg(psi,nl);
    else
      C = abs(psi);
    end
    
    surf(x, y, V/max(max(V)), 'FaceAlpha',transp, 'EdgeColor','interp', ...
	 'SpecularColorReflectance',.5, 'BackFaceLighting','lit');
    xlabel('x')
    ylabel('y')

    set(gca,'nextplot','replacechildren');

    hold on 
    
    surf(x, y, scim*abs(psi), C, 'FaceColor','interp', ...
	 'EdgeColor', 'interp', 'SpecularColorReflectance',.5, ...
	 'BackFaceLighting','lit');
    
    material shiny
    shading interp
    
    axis off
    view([Long+(90-Long)*t/Tmax,Latout+(Latin-Latout)*(1-t/Tmax)]);
    daspect([1,1,1/sqrt(L1*L2)])
    drawnow
    
    if(capt=='y')
      F(n) = getframe;
    end
    n = n+1;
    hold off
  end
  
%  close(h);

  
  final = set2{1};
  if (final(1)=='y' | final(1)=='Y'),
    clear choice;
    clear U W phi
    if(capt=='y')
      eval(['save ' set2{2} '_movie F']);
      clear F
    end
    eval(['save ' set2{2}]);
  end

  
  
%%%  Auxiliary functions
% Arg() needed for plotting surface

function A = arg(F, nl)
  warning off all
  A = (pi + imag(log(F))) .* (abs(F)>nl);
  
%%------------------------  
%% Potential hump inside a ball sith radius z

function b = Ball(x,y,z)
  
  b = sqrt(x.^2+y.^2)<z;
  
%%------------------------
%% Potential barrier with head at "head() and wifth "thick""

function f = Barrier(x, y, thick,  head, dir)
  
  f =  (abs(x-head(1))<thick).*(y*dir>head(2));
  
  
  
  
  
  % camorbit(t*90/Tmax,0,'data',[ 0 0 1])


