function [set1,set2] = wms2_a(mode,set1,set2)
%% Wave packets in 2-D
% Insert one of the  potentials Pot[1-9] below or define a new one 
% The option "capture = y" saves the snapshots as jpeg images for
% subsequent movie production. Expect timings for jpeg 10 times
% longer.
% To use potential e.g. #1 insert 'eval(Pot1)' in the input dialog
% 'mode' can be 'S' (Schroedinger eq.) or 'W' (wave eq.)
%  E.Onofri, 2004-2014

if(nargin<1), mode='S'; end

fftw('planner','exhaustive');

selection = {'Resume','New setup'};
choice    = menu('Start',selection);

entries1 = {'Size', 'Grid', 'mass', 'time', 'snapshots', 'initMom', ...
            'x_0', '\sigma', 'V(x)', };

entries2 = {'save results', 'save file name', 'plot every...', ...
            'scale image', 'noise level', 'color code', 'view angle', ...
            'transparency', 'capture', 'movie name' };

switch choice
  case 1				% resume a previous run
    d = dir('*.mat');
    files = {d.name};
    fprompt = {num2cell((1:max(size(files)))'), files'};
    [fprompt{1,:}]
    fn = input('choose number > ');
    eval(['load ' files{fn}]);
    def1 = set1;
    def2 = set2;
  case 2
    % new run
    % several potential forms to be inserted in the table 'def1' below

    Pot1 = ' 100 * Ball(x,y,40)';
    
    Pot2 = ['10*(Ball(x,y,10)+Ball(x-20,y-20,10)+Ball(x-20,y+20,' ...
            '10)+Ball(x,y-40,10)+Ball(x,y+40,10)+Ball(x-20,y+60,' ...
            '10)+Ball(x-20,y-60,10)+Ball(x,y+80,10)+Ball(x,y-80,10))'];
    
    Pot3 =  '10*(Ball(x,y,12)+Barrier(x,y,12,[0,24],1)+Barrier(x,y,12,[0,24],-1))';
    
    Pot4 = '(Ball(x,y,20)-Ball(x,y,10))';
    
    Pot5 = ['1.0*ones(size(x)).*(Ball(x,y,8)+Ball(x-20,y-20,8)+' ...
            'Ball(x-20,y+20,8)+Ball(x,y-40,8)+Ball(x,y+40,8)+' ...
            'Ball(x-20,y+60,8)+Ball(x-20,y-60,8)+Ball(x,y+80,8)+' ...
            'Ball(x,y-80,8)+Ball(x-20,y+100,8)+Ball(x-20,y-100,8)+' ...
            'Ball(x,y+120,8)+Ball(x,y-120,8)+Ball(x-20,y+140,8)+' ...
            'Ball(x-20,y-140,8)+Ball(x,y+160,8)+Ball(x,y-160,8))'];
    
    Pot6 = 'exp(-(sqrt(x.^2+y.^2)-10).^2)'; % Annular barrier
    
    Pot7 = '-Yukawa(x,y)'; 
    
    Pot8 =  ['(Yukawa(x,y) + Yukawa(x+5,y+20)+Yukawa(x-5,y-20)+' ...
             'Yukawa(x+10,y+40)+Yukawa(x-10,y-40)+ Yukawa(x+15,y+' ...
             '60)+Yukawa(x-15,y-60)+Yukawa(x+20,y+80)+Yukawa(x-20,' ...
             'y-80)+Yukawa(x+25,y+100)+Yukawa(x-25,y-100)+' ...
             'Yukawa(x+30,y+120)+Yukawa(x-30,y-120))'];
    
    Pot9 = 'lattice(x,y,10,pi/12,10)';

    if(nargin<3)
       def2 = {'y',...
               'Store',...
               '4',...
               '2',...
               '.0001',...
               'phase',...
               '[-90,90,0,80]',...
               '.5',...
               'n',...
               'movie'
              };
    end
    
    if(nargin<2)
       def1 = {'[256.0,256.0]',... % Size
               '[512,512]',...  % NGrid
               '1.0',...  % mass
               '400.0',...   % time
               '400',...   % snapshots
               '[.5,0.]',...
               '[-160.0,0.0]',...
               '[36.0,1.e6]',...
               Pot3
              };       
    end
    
    if nargin==0
       def1 = set1;
       def2 = set2;
    end
end                                     % end switch mode

head1 = 'Initial data';
head2 = 'graphics data';
lines = 1;
AddOpts.Resize  =  'on';
AddOpts.WindowStyle  =  'normal';
AddOpts.Interpreter  =  'tex';

set1 = inputdlg(entries1,head1,lines,def1,AddOpts);
set2 = inputdlg(entries2,head2,lines,def2,AddOpts);

L = str2num(set1{1});
L1 = L(1);
L2 = L(2);

Ngrid = str2num(set1{2});
N1 = Ngrid(1);
N2 = Ngrid(2);

mass = str2num(set1{3});
Tmax = str2num(set1{4});
snapshots = str2num(set1{5});

mom = str2num(set1{6});
p1 = mom(1);
p2 = mom(2);

x0 = str2num(set1{7});
y0 = x0(2);
x0 = x0(1);

sigma = str2num(set1{8});
s1 = sigma(1);
s2 = sigma(2);

iter = str2num(set2{3});
scim = str2num(set2{4});
nl = str2num(set2{5});
color_code = set2{6};

angles = str2num(set2{7});
Longin = angles(1);
Longout = angles(2);

Latin = angles(3);
Latout = angles(4);

transp = str2double(set2{8});
capt = set2{9};
moviename=set2{10};

% build configuration space lattice using meshgrid
grdx = linspace(-L1,L1,N1);                                        
grdy = linspace(-L2,L2,N2);
[x,y] = meshgrid(grdx,grdy);
r = sqrt(x.^2+y.^2);

% build momentum space lattice
grdpx = pi*(0:N1-1)/L1;    
grdpy = pi*(0:N2-1)/L2;   
grdpx(N1/2:N1) = (grdpx(N1/2:N1)-pi*N1/L1)*(N1-1)/N1;
grdpy(N2/2:N2) = (grdpy(N2/2:N2)-pi*N2/L2)*(N2-1)/N2;

[kx,ky]=meshgrid(grdpx,grdpy);

if(mode=='W')
   k2 = sqrt(kx.^2+ky.^2); % optics
else
   k2 = kx.^2+ky.^2;
end

tau = Tmax/snapshots/iter;
t = 0.0;

eval(['V=',set1{9},';']);

K = min(0.5*k2/mass,pi/tau);
W = exp(-i*K*tau);

V  = min(V,pi/tau);			% antialiasing
V  = max(V,-pi/tau);			% antialiasing
U  = exp(-0.5*i*V*tau);
U2 = exp(-i*V*tau);

psi = exp(-(x-x0).^2/2/s1 ...
	  -(y-y0).^2/2/s2 ...
	  +i*p1*x+i*p2*y)/(pi*s1*pi*s2).^(1/4);

if(~isempty(findstr('phase',color_code))),
   C = arg(psi,nl);
else
   C = abs(psi);
end

% Calculate kinetic energy

phi=fft2(psi);
E = sum(sum(abs(phi).^2 .* k2))/(2*mass)/ sum(sum(abs(phi).^2));
E = E/max(max(abs(V)));
disp(['kinetic energy =',num2str(E),'%']);

surf(x, y, V/max(max(abs(V))),...
     'FaceAlpha',transp,...
     'EdgeColor','interp',...
     'SpecularColorReflectance',.5,...
     'BackFaceLighting','lit');

set(gca,'nextplot','replacechildren');
hold on 
axis tight
fill3(L1*[-1,1,1,-1,-1],L2*[1,1,-1,-1,1],E*[1,1,1, 1,1],'y', ...
      'FaceAlpha',transp/4);
drawnow

pause

surf(x, y, abs(psi/max(max(abs(psi)))).^2, C,...
     'FaceColor','interp',...
     'EdgeColor','interp',...
     'SpecularColorReflectance',.8,...
     'BackFaceLighting','lit');
axis tight
hold on
if(mode=='W')
   title_text='2-D Wave Equation';
else
   title_text='2-D Schroedinger Equation';
end

title(title_text,'color','w','FontSize',18)

material shiny
shading interp

view([Longin,Latin]);

axis([-L1,L1,-L2,L2,0,max(max(abs(psi).^2))])
daspect([1,1,1/sqrt(L1*L2)])

set(gcf,'DoubleBuffer','on');
set(gca,'nextplot','replacechildren');
set(gcf, 'color', [0,0,.55]);
set(gcf, 'InvertHardCopy', 'off')

n=1; % snapshot number

while(t<=Tmax),
   
   if(mode=='W')
      title_text=['2-D Wave Equation - t =', sprintf('%8.1f',t)];
   else
      title_text=['2-D Schroedinger Equation - t =', sprintf('%8.1f',t)];
   end
   
   % Trotter steps
   psi=psi.*U;     % leapfrog correction U(1/2)*W*U*W*...U*W*U(1/2)
   for j = 1:iter,
      psi = U2.*ifft2(W.*fft2(psi));
      t = t+tau; 
   end
   psi=psi.*conj(U);         % end Trotter
   
   if(~isempty(findstr('phase',color_code))),
      C = arg(psi,nl);
   else
      C = abs(psi)/max(max(abs(psi)))*pi;
   end
   
   surf(x, y, V/max(max(abs(V))), 'FaceAlpha',transp, ...
        'EdgeColor','interp', 'SpecularColorReflectance',.5, ...
        'BackFaceLighting','lit');

   set(gca,'nextplot','replacechildren');
   
   hold on 
   axis tight
   surf(x, y, abs(psi/max(max(abs(psi)))).^2, C, 'FaceColor','interp', ...
        'EdgeColor', 'interp', 'SpecularColorReflectance',.5, ...
        'BackFaceLighting','lit');
   
   material shiny
   shading interp

   title(title_text,'color','w','FontSize',18)
   
   axis off
   rotate=t/Tmax;
   view([Longin + (Longout-Longin)*rotate,Latout+(Latin-Latout)*rotate]);
   daspect([1,1,1/sqrt(L1*L2)])
   drawnow
   ver=sprintf('%d',1000000+n);

   if(capt=='y')
      print('-djpeg75',['images/',moviename,ver]);
   end

   n=n+1;
   
   hold off
end

final = set2{1};
if (final(1)=='y' | final(1)=='Y'),
   clear choice;
   clear U W phi U2 psi
   eval(['save ' set2{2}]);
end



%%%  Auxiliary functions
% Arg() needed for plotting surface

function A = arg(F, nl)
warning off all
A = (pi + imag(log(F))) .* (abs(F)>nl);

%%------------------------  
%% Potential hump inside a ball sith radius z

function b = Ball(x,y,z)

b = sqrt(x.^2+y.^2)<z;

%% Potential barrier with head at "head() and width "thick""

function f = Barrier(x, y, thick,  head, dir)

f =  (abs(x-head(1))<thick).*(y*dir>head(2));


%% Yukawa
function f = Yukawa(x,y)  
core=1e-10;
r=sqrt(x.^2+y.^2+core);
f=1./r.*exp(-r/20);


%%% lattice: a regular array of diffusion centers with inclination
%"slope" w.r.t. the incoming particle

function f = lattice(x,y,a,slope,N,M)
if nargin < 6
   M=1
end

f=Yukawa(x,y);
d1x=a*sin(slope);
d1y=a*cos(slope);
d2y=a*sin(slope);
d2x=-a*cos(slope);


for j=-N:N,
   for k=0:M-1
      f=f+Yukawa(x+j*d1x+k*d2x,y+j*d1y+k*d2y);
   end
end

%%%%%%%%%%