function [sigma] = cross_sect(theta, k, shifts)
%CROSS_SECT Calcola la sezione d'urto differenziale in funzione dell'angolo 
% theta con il metodo dei phase shifts.
%
%  [sigma] = CROSS_SECT(theta, k, shifts)
%       theta   vettore degli angoli
%       k       vettore con i numeri d'onda
%       shifts  matrice di dimensioni maxell*length(k). Ogni colonna contiene
%               gli sfasamenti per ogni l
%       sigma   vettore di dimensione length(theta) *  length(k). Contiene in
%               colonna la sezione d'urto differenziale in funzione di theta per il k
%               corrispondente.
%
%  Esempi:
%  t = linspace(0,pi,200);
%  sigma = crosssect(t, k, shifts);
%  plot(t, sigma(:,1));
%
%  La sezione d'urto totale pu essere ottenuta integrando sull'angolo
%  solido:
%
%  sigma_tot = 2*pi*trapz(t, sin(t).*sigma(:,1))

% V. Calogero eq (2.11)

sigma = zeros(length(theta),length(k));

    for l = 0: size(shifts,1) - 1
        
        f = zeros(length(theta),length(k));
        %Polinomi di Legendre di cos(theta), m = 0
        P = legendre(l,cos(theta));
        P = P(1,:); % La prima riga  per m = 0

        for n = 1:length(k)
            %Somma cumulativa
            f(:,n) = (2*l + 1)*exp(1i*shifts(l+1,n))*sin(shifts(l+1,n))*P./k(n);
        end

        sigma = sigma + f;
    end
    sigma = abs(sigma).^2;
end