function [ t, sigma ] = cross_sect(t, k, ps )
%CROSS_SECT Calcola la sezione d'urto differenziale
%   [ t, sigma ] = CROSS_SECT(t, k, ps )
%   t:      vettore contente gli angoli (in rad)
%   k:      vettore RIGA contente i numeri d'onda
%   ps:     vettore di dimensione max_ell * length(k). Ogni colonna 
%           contiene i delta_l per ciascun vettore d'onda k
%   
%   sigma:  vettore di dim. t * max_ell * length(k). Contiene la sezione d'urto
%           differenziale per ogni k.

tt = length(t);

[l, nk] = size(ps);
ell = repmat((1:l)'*ones(1,nk),[1 1 tt]);
km =repmat(ones(l,1)*k,[1 1 tt]);
pss = repmat(ps,[1 1 tt]);
P = zeros(l,nk,tt);
a = zeros(1,1,tt);

for i = 1:l
   pl = legendre(i-1,cos(t));
   a(1,1,:) = pl(1,:);
   P(i,:,:) = repmat(a,[1 nk 1]);
end

S = 2.*ell.*exp(1i.*pss).*sin(pss).*P./km;

S = cumsum(S);
sigma = abs(S).^2;  
sigma = permute(sigma,[3 1 2]);
end