function [k_grid, delta,setup] = phasefn(default, batch)
% Funzione di fase per la diffusione in campo centrale
% adapted from Calogero's "Variable Phase approach to potential
% scattering", AcadPress 1967
% Usage:
%  [k,delta,setup] = phasefn(setup)
%  delta contains the phase shift at various k's

    entries = {'r_{max}',...
               'ell',...
               'tol'...
               'V_0',...
               '\eta',...
               'hc',...
               'k interval (waves/nm)',...
               'nk',...                 % number of points in k
               'save to mat?<y/n>',...
               'save to fname:'
              };
    
    if nargin<1,
        default = {'20',... % size
                   '0',...
                   '1.e-8',...
                   '-.5',...
                   '.1',...
                   '0.005',...
                   '[0.1, 1.]',...
                   '200',...
                   'n',...
                   'mat/phfn_0'
                  };
    end
    
    AddOpts.Resize       =  'on';
    AddOpts.WindowStyle  =  'normal';
    AddOpts.Interpreter  =  'tex';
    
    if nargin<2,
       setup = inputdlg(entries,'parameters',1,default,AddOpts);
    else
       setup=default;
    end

    rmax = str2num(setup{1});
    ell  = str2num(setup{2});
    tol  = str2num(setup{3});
    V0   = str2num(setup{4});
    eta  = str2num(setup{5});
    hc = str2num(setup{6});
    k_intvl = str2num(setup{7});
    nk = str2num(setup{8});
    fout  = setup{10};

    delta = [];
    k_grid = linspace(k_intvl(1),k_intvl(2),nk);
    
    opt = odeset('RelTol',tol,...
                 'AbsTol',tol,...
                 'refine',2);
    
    r_intvl = [hc, rmax];

    hwb = waitbar(0,'Please wait...');
    
    for i = 1:length(k_grid),              % scanning momentum space
        k = k_grid(i);
        waitbar(k/max(k_grid));
        [r,d]=ode113(@phf,r_intvl,0,opt,k);
        delta = [delta, d(end)];         % only the last value is significant?
    end
    close(hwb);
    
    hpl=plot(k_grid.^2/2, 4*pi*sin(delta).^2./k_grid.^2,'.-');
    set(gcf,'WindowStyle','docked')
    title(['\sigma_',num2str(ell)],'FontSize',14)
    xlabel('E','FontSize',14)

    if lower(setup{9})=='y',
       eval(['save ' fout])
    end
    
    function V=pot(r)
    %       V = V0*exp(-eta*r)./r;
       V = V0;    % potenziale costante per r<rmax
    end
    
    function dy = phf(r,y,k)
       dy = -pot(r).*(cos(y).*j(ell, k*r) - sin(y).*n(ell,k*r)).^2/k;
    end
 end
 
%% Spherical functions (Riccati Bessel -  j_n ~ sin(x-l pi/2) -
%   notice that there is a factor x w.r.t. the spherical Bessel
%  fncs.


function Y = j(ell,x)
  Y = sqrt(pi*x/2).*besselj(ell+1/2,x);
end

function Y = n(ell,x)
   Y = sqrt(pi*x/2).*bessely(ell+1/2,x);
end


