function [setup, k, sigma] = run_phfn(maxell,default)
% MULTIPLE RUNS OF "phasefn.m"

if nargin<1, maxell=10;end

 entries = {'r_{max}',...
            'ell',...
            'tol'...
            'V_0',...
            '\eta',...
            'hard core',...
            '[kmin, kmax] (waves/nm)',...
            'number of k interv',...                 % number of points in k
            'save mat?',...
            'save to...'
           };
 
 AddOpts.Resize  =  'on';
 AddOpts.WindowStyle  =  'normal';
 AddOpts.Interpreter  =  'tex';
 
 if nargin<2
    default = {'20',... % size
               '0',...                  % elle
               '1.e-6',...              % accuracy
               '.125',...                % V_0
               '1.0'...,                 % eta
               '.005',...               % hard core
               '[0.0125, 1.]',...          % k interval
               '200',...                % number of k-values
               'n',...
               'mat/phfn_00'                % save to fname
              };
end

setup = inputdlg(entries,'parameters',1,default,AddOpts);

disp(['Start running at elle = 0'])

[k, delta] = phasefn(setup, 1);

ps = delta;
tic
for ell = 1:maxell,
    setup{2} = num2str(ell);
    if ell<10,
       setup{10}(end) = num2str(ell);       % adjust file name where
                                            % data are saved
    else
       setup{10}(end-1:end) = num2str(ell);   
    end
    disp(['Now running at ell = ',num2str(ell)])
    [k, delta] = phasefn(setup, 1);
    ps = [ps;delta];
end

time_On = toc;

[m,n]=size(ps);

ell = (0:maxell)'*ones(1,n);
S = (2*ell+1).*sin(ps).^2;
CS= cumsum(S);
km=ones(maxell+1,1)*k;

% sezione d'urto parziale e totale (incrementale per onde parziali)
sigma = 4*pi./km.^2 .* CS;      % valutare i contributi aggiuntivi dei mom
                                % angolari superiori

setup{2}='0';                           % back to initial ell

figure
plot(k.^2,sigma);
set(gcf,'WindowStyle','docked')
xlabel('E','FontSize',14)
ylabel('\sigma_{tot}(k)','FontSize',14)

figure
surf(km.^2, ell, sigma,...
     'FaceAlpha',.5,...
     'EdgeColor','interp',...
     'SpecularColorReflectance',.5,...
     'BackFaceLighting','lit');
set(gcf,'WindowStyle','docked')
xlabel('E','FontSize',14)
ylabel('\Sigma_l\sigma_{l}(k)','FontSize',14)
title('Cumulative cross section')
