function [setup, k, ps, sigma] = run_phsh(maxell,default)
% MULTIPLE RUNS OF "phaseshifts.m"
% Input: maximal value of angular momentum = maxell
%        default is the setup prepared by previous runs
% Output: setup - to use in further runs
%         k = wave number
%         ps= phase shifts
%         sigma= total cross section
% Usage:
%  >> [setup, k, ps, sigma] = run_phsh(maxell,default)

if nargin<1, maxell=10;end

entries = {'r_{max}',...            % cutoff sul raggio
           'ell',...                % momento angolare
           'tol'...                 % accuratezza richiesta  a ode113
           'V_0',...                % coupling
           '\eta',...               % Yukawa parameter
           'hard core',...          % 
           '[k_min, k_max] (waves/nm)',... % wave number interval
           'number of k interv',...        % number of points in momentum space
           'save <y/n>',...
           'save to...'
          };

AddOpts.Resize  =  'on';
AddOpts.WindowStyle  =  'normal';
AddOpts.Interpreter  =  'tex';

if nargin<2
   default = {'20',... % size
              '0',...
              '1.e-6',...
              '.125',...
              '1.0',...
              '.005',...
              '[.0125, 1]',...
              '100',...
              'n',...
              'mat/phsh_00',...
             };
end

setup = inputdlg(entries,'parameters',1,default,AddOpts);

disp(['Start running at elle = 0'])

[k, delta] = phaseshifts(setup, 1);

ps = delta;

for ell = 1:maxell,
   setup{2} = num2str(ell);
   if ell<10,
      setup{10}(end) = num2str(ell);       % adjust file name
                                           % where data are saved
   else
      setup{10}(end-1:end) = num2str(ell);       
   end
   
   disp(['Now running at elle = ',num2str(ell)])
   [k, delta] = phaseshifts(setup, 1);
   ps = [ps;delta];
end

[m,n]=size(ps);

ell = (0:maxell)'*ones(1,n);
S = (2*ell+1).*sin(ps).^2;
CS= cumsum(S);
km=ones(maxell+1,1)*k;

% sezione d'urto parziale e totale (incrementale per onde parziali)
sigma = 4*pi./km.^2 .* CS;      % valutare i contributi
                                % aggiuntivi dei mom
                                % angolari superiori

setup{2}='0';                           % back to initial ell

figure
plot(k.^2,sigma)
set(gcf,'WindowStyle','docked')
xlabel('k^2','FontSize',14)
ylabel('\Sigma_0^l\sigma_l(k)','FontSize',14)

if(setup{9}=='y'),
   save setup{10}
end
