function [delta,eta] = Perturb(N)
% Usage: [delta,eta] = Perturb(N)
% calcola lo sviluppo perturbativo del ground state
% per l'oscillatore perturbato con V=x^4
% N.B. Per ottenere delta interi si e` moltiplicato lambda per 4!!!!!!
% N=massimo ordine perturbativo, 
% delta=coefficienti nello sviluppo perturbativo dello stato fondamentale
% eta{n}==|eta_n>
% L'aritmetica finita non permette di superare 14 ordini 
% Onofri & Mori 2006 

if nargin<1, N=3;end

Nmax = 6*N; 

n = (1:Nmax)';
% rappresentazione di a ad sugli interi see paper Fateev&Onofri
a  = spdiags(n-1,1,Nmax,Nmax); % annichilatore: nota che gli
                                     % indici in matlab devono
                                     % partire da uno!

ad = spdiags(ones(size(n)),1,Nmax,Nmax); % creatore
ad=ad';

R = spdiags([0;1./n],0,Nmax,Nmax);   % risolvente nel
                                     % sottospazio ortogonale al vuoto

H1 = (a+ad)^4; 
 
v{1} = sparse(Nmax,1); % i vettori sono realizzati in termini di
                       % matrici sparse per economia di memoria e
                       % velocit? di esecuzione
				
v{1}(1) = 1;	       % questo ? |0>

eta{1} = v{1};
w01 = v{1}'*H1; % queste combinazioni compaiono in tutte le iterazioni e

delta(1) =  w01*eta{1};
disp(num2str(delta(1)))
eta{2} = -R*H1*eta{1};
delta(2) = w01*eta{2};
disp(num2str(delta(2)))

for(j=3:N),				% start iteration
  
   Wtmp = -H1*eta{j-1};
   
   for(k=1:j-2),		    % se j<2 k ? una matrice
                                    % vuota e il loop viene saltato
      Wtmp = Wtmp+delta(k)*eta{j-k};
      
   end
   
   eta{j} = R*Wtmp;
   try
      delta(j) =   w01*eta{j};
   catch
      error(['error in delta',num2str(j)])
      rethraw(lasterror)
   end
  disp(num2str(delta(j)))
end

