function [delta,eta] = Perturb_n_2(N, E0)
% Usage: [delta,eta] = susypt(N, E0)
% calcola lo sviluppo perturbativo 
% per l'oscillatore perturbato con V=x^4
% N=massimo ordine perturbativo, 
% E0 = energia dello stato imperturbato (E0=0, 1, 2, ...)
% delta=coefficienti nello sviluppo perturbativo dello stato fondamentale
% eta{n}==|eta_n>
% L'aritmetica finita non permette di superare 14 ordini 
% Onofri & Mori 2006 

if nargin<2, E0=0; end
if nargin<1, N=5; end

Nmax = 6*N; 
n = (1:Nmax)';
% rappresentazione di a ad sugli interi see paper Fateev&Onofri
a = spdiags(sqrt(n-1),1,Nmax,Nmax); % annichilatore: nota che gli
                                     % indici in matlab devono
                                     % partire da uno!
ad = a';
E = (n-1).^2;
R = E-E0^2;
ind = R~=0;
R(ind) = 1./R(ind);

R = spdiags(R,0,Nmax,Nmax);   % risolvente nel
                                     % sottospazio ortogonale al vuoto

V = ad*a^2+ad^2*a;

v{1} = sparse(Nmax,1); % i vettori sono realizzati in termini di
                       % matrici sparse per economia di memoria e
                       % velocit? di esecuzione
				
v{1}(E0+1) = 1;	       % questo ? |0>

eta{1} = v{1};
w0 = v{1}'*V;         % questa combinazione compare in tutte le iterazioni

delta(1) =  w0*eta{1};
disp(num2str(delta(1)))
eta{2} = -R*V*eta{1};
delta(2) = w0*eta{2};
disp(num2str(delta(2)))

for(j=3:N),				% start iteration
  
   Wtmp = -V*eta{j-1};
   
   for(k=1:j-2),		    % se j<2 k ? una matrice
                                    % vuota e il loop viene saltato
      Wtmp = Wtmp+delta(k)*eta{j-k};
      
   end
   
   eta{j} = R*Wtmp;
   try
      delta(j) =   w0*eta{j};
   catch
      error(['error in delta',num2str(j)])
      rethraw(lasterror)
   end
  disp(num2str(delta(j)))
end

