function [delta,eta] = susypert(N)
% Usage: [delta,eta] = susypt(N)
% calcola lo sviluppo perturbativo del ground state
% per l'oscillatore perturbato con il potenziale supersimmetrico
% N=massimo ordine perturbativo, 
% delta=coefficienti nello sviluppo perturbativo dello stato fondamentale
% eta{n}==|eta_n>
% L'aritmetica finita non permette di superare 14 ordini 
% Onofri & Mori 2006 

Nmax = 6*N; 

n = (1:Nmax)';
% rappresentazione di a ad sugli interi see paper Fateev&Onofri
a  = spdiags(n-1,1,Nmax,Nmax); % annichilatore: nota che gli
                                     % indici in matlab devono
                                     % partire da uno!

ad = spdiags(ones(size(n)),1,Nmax,Nmax); % creatore
ad=ad';

R = spdiags([0;1./n],0,Nmax,Nmax);   % risolvente nel
                                     % sottospazio ortogonale al vuoto

x = (a+ad);			% i fattori sqrt(2) sono spostati nella
H1 = x^4/4 + 3/4*x^2;% definizione di H1 e H2 per ridurre
H2 = x^6/16;         % gli errori di taglio
 
v{1} = sparse(Nmax,1); % i vettori sono realizzati in termini di
                       % matrici sparse per economia di memoria e
                       % velocit? di esecuzione
				
v{1}(1) = 1;	       % questo ? |0>

eta{1} = v{1};
w01 = v{1}'*H1; % queste combinazioni compaiono in tutte le iterazioni e
w02 = v{1}'*H2; % quindi conviene calcolarle una volta sola all'inizio

delta(1) =  w01*eta{1};
disp(num2str(delta(1)))
eta{2} = -R*H1*eta{1};
delta(2) = w01*eta{2}+w02*eta{1};
disp(num2str(delta(2)))

for(j=3:N),				% start iteration
  
  Wtmp = -H1*eta{j-1}-H2*eta{j-2};
  
  for(k=1:j-2),		    % se j<2 k ? una matrice
                            % vuota e il loop viene saltato
    Wtmp = Wtmp+delta(k)*eta{j-k};
  
  end

  eta{j} = R*Wtmp;
  try
      delta(j) =   w01*eta{j}+w02*eta{j-1};
  catch
      error(['error in delta',num2str(j)])
      rethraw(lasterror)
  end
  disp(num2str(delta(j)))
end

