function [rho,tau,W]=tunnel
% Compute the transmission and reflection amplitudes for a given
% potential barrier. Units are Lenght=1.e-9 m, k is the wave number
% measured in 1e9/m, mass is in units of electron's mass, the
% potential is normalized to V_0 times the expression returned by
% the function pot(x,...)

  selection = {'Resume','New setup'};
  choice    = menu('Start',selection);

  entries = {'Size (L/nm)',...
	     'mass (m/m_e)',...
	     'tol'...
	     'V_0 (eV)',...
	     'k (waves/nm)',...
             'save to...'
	   };
  
  switch choice
   case 1				% resume a previous run
    d = dir('*.mat');
    files = {d.name};
    fprompt = {num2cell((1:max(size(files)))'), files'};
    [fprompt{1,:}]
    fn = input('choose number > ');
    eval(['load ' files{fn}]);
    default = setup;
   case 2				% new run
    
    default = {'1.0',... % size
               '1.0',...  % mass
               '1.e-10',...
               '1.0',...
               '[0.1:0.1:5.]',...
               'tunnel_1'
              };
  end
  
  AddOpts.Resize  =  'on';
  AddOpts.WindowStyle  =  'normal';
  AddOpts.Interpreter  =  'tex';
  
  setup = inputdlg(entries,'parameters',1,default,AddOpts);
  
  a = 1e-9*str2num(setup{1});		% units nanometers
  mass = 9.109e-31*str2num(setup{2});	% units in electron mass
  tol =str2num(setup{3});
  V0 = 1.6e-19*str2num(setup{4});	% energy in eV
  k_interval=1e9*str2num(setup{5});	% units 10^9/meter
  hbar = 6.626e-34;                     % MKS
  eta=2*mass*a^2*V0/hbar^2;

  options=odeset('RelTol', tol,...
                 'AbsTol', tol,...
                 'refine',1);

  supp=[-1,1];				% support of interaction region
  
  tau=[];
  rho=[];
  h = waitbar(0,'Please wait...');
  n=1;
  
  for k=k_interval,
    waitbar(k/max(k_interval));
    ka=k*a;
    uin=[exp(i*ka), -i*ka*exp(i*ka)];	% wf and its derivative at x=-a
  
    % propagate from x=-a to x=a using Schrodinger equation
    
    [x,u] = ode113(@schreq, supp, uin, options, ka^2, eta);

    % get end values at x=a and connect to plane waves

    uf = u(end,1);
    upf= u(end,2);
  
    A = 1/2*exp(i*ka)*uf - exp(i*ka)*upf/(2*i*ka);
    B = 1/2*exp(-i*ka)*uf + exp(-i*ka)*upf/(2*i*ka);

    % Now get the reflection and transmision amplitudes  
    tau = [tau;1/A];
    rho = [rho;B/A];

    W{n}=[conj(A), -conj(B); -B,A];
    n=n+1;
    
    % check that unitarity is satisfied
  end
  close(h);
  
  err= sum(1 - sqrt((abs(tau).^2+abs(rho).^2)))/length(tau);
  disp(['Unitarity error =',num2str(err)]);

  
  k_crit=sqrt(abs(eta)/a^2)*1e-9;
  
  plot(k_interval*1e-9,abs(tau).^2,'g',...
       k_interval*1e-9,abs(rho).^2,'r','LineWidth',2)
  xlabel('k (waves/nanometer)')
  title('Tunnel effect')
  hold on
  
  plot(k_crit*[1,1],[0,1],'--');
  legend('|\tau(k)|^2','|\rho(k)|^2','k_{min}')
  axis tight
  
  if(~isempty(setup{6}))
    eval(['save ', setup{6}]);
  end
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
% Here insert your favourite potential - default square barrier

function V=pot(x)
  
%  V = 1;
%   V = (x.^2-1).^2;
% V = 1./cosh(x).^2;
 V = 1-abs(x);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
% stationary Schrodinger equation 

function  psixx = schreq(x, psi, ka2, eta)

  psixx=[psi(2); (eta*pot(x) - ka2)*psi(1)];
