function [rho,tau,W]=tunnel1
% Compute the transmission and reflection amplitudes for a given
% potential barrier.
% NB: Unita` di misura arbitrarie
% Equation: psi''+(ka)^2 psi = 2mV(xi)a^2/hbar^2 psi(xi)
% xi  = x/a
% ©E.Onofri, 2011-2013
   

   selection = {'Resume','New setup'};
   choice    = menu('Start',selection);
   
   entries = {'Size (L/nm)',...
              'mass (m/m_e)',...
              'tol'...
              'V_0 (eV)',...
              'k (waves/nm)',...
              'save to...'
             };
   
   switch choice
     case 1				% resume a previous run
       d = dir('*.mat');
       files = {d.name};
       fprompt = {num2cell((1:max(size(files)))'), files'};
       [fprompt{1,:}]
       fn = input('choose number > ');
       eval(['load ' files{fn}]);
       default = setup;
     case 2				% new run
       
       default = {'1.0',... % size
                  '1.0',...  % mass
                  '1.e-10',...
                  '1.0',...
                  '[0.1:0.05:5.]',...
                  'tunnel_1'
                 };
   end
   
   AddOpts.Resize  =  'on';
   AddOpts.WindowStyle  =  'normal';
   AddOpts.Interpreter  =  'tex';
   
   setup = inputdlg(entries,'parameters',1,default,AddOpts);
   
   a    = str2num(setup{1});        % units nanometers
   mass = str2num(setup{2});	% units converted from
                                        % electron mass to Kg
   tol  = str2num(setup{3});
   eta  = str2num(setup{4});	% energy converted from eV
                                        % to joule
   k_interval = str2num(setup{5});	% units 10^9/meter
   hbar = 1;
   
   options=odeset('RelTol', tol,...
                  'AbsTol', tol,...
                  'refine',1);
   
   supp=[-1,1];				% support of interaction
                                        % region in xi=x/a
    scrsz = get(0,'ScreenSize');
    fig = figure('Position',[1, 1, scrsz(3)/2, scrsz(4)/2]);
    
    set(fig,'DoubleBuffer','on','Windowstyle','docked');
    set(gca,'NextPlot','replace','Visible','off')
   
   tau=[];
   rho=[];
   h = waitbar(0,'Please wait...');
   
   n=1;
   
   for k=k_interval,
      waitbar(k/max(k_interval));
      ka=k*a;
      uin=[exp(i*ka), -i*ka*exp(i*ka)];	% wf and its derivative at x=-a

      % propagate from x=-a to x=a using Schrodinger equation
      % starting from -a and plane wave exp(-ikx) - transmitted wave
    
      [x,u] = ode113(@schreq, supp, uin, options, ka^2, eta);
      
      % get end values at x=a and connect to plane waves
      
      uf = u(end,1);
      upf= u(end,2);
  
    A = 1/2*exp(i*ka)*(uf + i*upf/ka);
    B = 1/2*exp(-i*ka)*(uf -i*upf/ka);

    % Now get the reflection and transmision amplitudes  
    tau = [tau;1/A];
    rho = [rho;B/A];

    W{n}=[conj(A), -conj(B); -B,A];
    n=n+1;
    
    % check that unitarity is satisfied
  end
  close(h);
  
  err= abs(sum(1 - sqrt((abs(tau).^2+abs(rho).^2)))/length(tau));
  disp(['Unitarity error =',num2str(err)]);

  
  k_crit=sqrt(eta/a^2);
  kmin=k_interval(1);
  kmax=k_interval(end);

  plot(k_interval,abs(tau).^2,'g',...
       k_interval,abs(rho).^2,'r','LineWidth',3)
  set(gca,'Color',    [.8,.8,.8])
  set(gcf,'DoubleBuffer','on');
  xlabel('k (waves/nanometer)')
  title('Tunnel effect')
  hold on

  plot(k_crit*[1,1],[-0.025,1.025],'--')
  L1=legend('|\tau(k)|^2','|\rho(k)|^2','{\sl k_{crit}}');
  axis([0,max(k_interval),-.025,1.025]);
  set(L1,'FontSize',14,...
         'FontWeight','b')
  hold on
  plot([kmin,kmax],[1,1],'--',[kmin,kmax],[0,0],'--')
  %  axis tight
  
  if(~isempty(setup{6}))
    eval(['save ', setup{6}]);
  end
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
% Here insert your favourite potential - default square barrier

function V=pot(x)
%  V = 1./cosh(x).^2;
   V = 1./cosh(x);
%  V = 1;
%   V = (x.^2-1).^2;
%   V = 1./cosh(x).^2;
%   V = 1-abs(x);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
% stationary Schrodinger equation 

function  psixx = schreq(x, psi, ka2, eta)

  psixx=[psi(2); (eta*pot(x) - ka2)*psi(1)];
